@@ -50,7 +50,7 @@ class Endpoints(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not (self.addresses and self.ports):
                 raise MissingRequiredArgumentError(argument="'addresses' and 'ports")
 
