@@ -31,7 +31,7 @@ class HyperConverged(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if self.infra:
                 self.res.setdefault("spec", {}).setdefault("infra", {}).update(self.infra)
 
