@@ -35,6 +35,6 @@ class NodeMaintenance(Resource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             assert self.node, "node is mandatory for create"
             self.res["spec"] = {"nodeName": self.node.name, "reason": self.reason}
